==> huaweicloudsdkworkspace-3.1.133-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/list_agents_install_condition_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListAgentsInstallConditionResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'agents_condition': 'list[AgentsCondition]',
        'total_count': 'int'
    }

    attribute_map = {
        'agents_condition': 'agents_condition',
        'total_count': 'total_count'
    }

    def __init__(self, agents_condition=None, total_count=None):
        """ListAgentsInstallConditionResponse

        The model defined in huaweicloud sdk

        :param agents_condition: 桌面agent安装情况
        :type agents_condition: list[:class:`huaweicloudsdkworkspace.v2.AgentsCondition`]
        :param total_count: 总共条数。
        :type total_count: int
        """
        
        super(ListAgentsInstallConditionResponse, self).__init__()

        self._agents_condition = None
        self._total_count = None
        self.discriminator = None

        if agents_condition is not None:
            self.agents_condition = agents_condition
        if total_count is not None:
            self.total_count = total_count

    @property
    def agents_condition(self):
        """Gets the agents_condition of this ListAgentsInstallConditionResponse.

        桌面agent安装情况

        :return: The agents_condition of this ListAgentsInstallConditionResponse.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.AgentsCondition`]
        """
        return self._agents_condition

    @agents_condition.setter
    def agents_condition(self, agents_condition):
        """Sets the agents_condition of this ListAgentsInstallConditionResponse.

        桌面agent安装情况

        :param agents_condition: The agents_condition of this ListAgentsInstallConditionResponse.
        :type agents_condition: list[:class:`huaweicloudsdkworkspace.v2.AgentsCondition`]
        """
        self._agents_condition = agents_condition

    @property
    def total_count(self):
        """Gets the total_count of this ListAgentsInstallConditionResponse.

        总共条数。

        :return: The total_count of this ListAgentsInstallConditionResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this ListAgentsInstallConditionResponse.

        总共条数。

        :param total_count: The total_count of this ListAgentsInstallConditionResponse.
        :type total_count: int
        """
        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListAgentsInstallConditionResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspace-3.1.155-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/list_agents_install_condition_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListAgentsInstallConditionResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'agents_condition': 'list[AgentsCondition]',
        'total_count': 'int'
    }

    attribute_map = {
        'agents_condition': 'agents_condition',
        'total_count': 'total_count'
    }

    def __init__(self, agents_condition=None, total_count=None):
        r"""ListAgentsInstallConditionResponse

        The model defined in huaweicloud sdk

        :param agents_condition: 桌面agent安装情况
        :type agents_condition: list[:class:`huaweicloudsdkworkspace.v2.AgentsCondition`]
        :param total_count: 总共条数。
        :type total_count: int
        """
        
        super(ListAgentsInstallConditionResponse, self).__init__()

        self._agents_condition = None
        self._total_count = None
        self.discriminator = None

        if agents_condition is not None:
            self.agents_condition = agents_condition
        if total_count is not None:
            self.total_count = total_count

    @property
    def agents_condition(self):
        r"""Gets the agents_condition of this ListAgentsInstallConditionResponse.

        桌面agent安装情况

        :return: The agents_condition of this ListAgentsInstallConditionResponse.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.AgentsCondition`]
        """
        return self._agents_condition

    @agents_condition.setter
    def agents_condition(self, agents_condition):
        r"""Sets the agents_condition of this ListAgentsInstallConditionResponse.

        桌面agent安装情况

        :param agents_condition: The agents_condition of this ListAgentsInstallConditionResponse.
        :type agents_condition: list[:class:`huaweicloudsdkworkspace.v2.AgentsCondition`]
        """
        self._agents_condition = agents_condition

    @property
    def total_count(self):
        r"""Gets the total_count of this ListAgentsInstallConditionResponse.

        总共条数。

        :return: The total_count of this ListAgentsInstallConditionResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        r"""Sets the total_count of this ListAgentsInstallConditionResponse.

        总共条数。

        :param total_count: The total_count of this ListAgentsInstallConditionResponse.
        :type total_count: int
        """
        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListAgentsInstallConditionResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
